genshi.template.text

Package genshi :: Package template :: Module text |

# Module text

Plain text templating engine.

This module implements two template language syntaxes, at least for a certain transitional period. OldTextTemplate (aliased to just TextTemplate) defines a syntax that was inspired by Cheetah/Velocity. NewTextTemplate on the other hand is inspired by the syntax of the Django template language, which has more explicit delimiting of directives, and is more flexible with regards to white space and line breaks.

In a future release, OldTextTemplate will be phased out in favor of NewTextTemplate, as the names imply. Therefore the new syntax is strongly recommended for new projects, and existing projects may want to migrate to the new syntax to remain compatible with future Genshi releases.

Classes
| NewTextTemplate Implementation of a simple text-based template engine.
| OldTextTemplate Legacy implementation of the old syntax text-based templates.
| TextTemplate Legacy implementation of the old syntax text-based templates.